@@ -1,17 +1,19 @@
 # Hyperlink-Men fr TeX/LaTeX-Syntax-Help
 #
-# Copyright (C) 1999  G. Lamprecht, W. Lotz, R. Weibezahn; IWD, Bremen University
+# Copyright (C) 2004  G. Lamprecht, W. Lotz, R. Weibezahn; IWD, Bremen University
 
 proc TeX_syntax_help  {format raise} {# Hypertext version of xtem-syntax-help
 
-proc hlpWinFill {window filedir entry} {
+proc hlpWinFill {window filedir args} {
  global Wh hlp_dir hlpStack hlpFiledir hlp_bmlist
+ TestPut 3 "<$window><$filedir><$args>" 
+    set entry $args; # otherwise error with empty args!
 
  if ![winfo exists $window] return
 
  $Wh.a.2.b configure -state disabled; $Wh.a.2.t configure -state disabled; update
  if {$filedir=="miscellaneous/mainhelp"} {set hlpStack ""}
- lvarpush hlpStack $entry;  lvarpush hlpStack $filedir
+ LvarPush hlpStack $entry;  LvarPush hlpStack $filedir
  set c_filedir $filedir
  set c_entry   $entry
  if {"$c_filedir"==""} {set c_filedir "???"}
@@ -42,7 +44,7 @@ proc hlpURLCall {filedir} {# calls Browser (e.g. netscape) according to urlcalle
    TestPut 3 "<$i><$urlcallexec($i)>"
    eval regsub -all will_be_replaced_on_the_fly_by_URL \"$urlcallexec($i)\" $filedir callstr
    TestPut 3 "   <$callstr>"
-   SigChldB; set notStarted [catch {eval exec $callstr} mes]; SigChldU
+   set notStarted [catch {eval exec $callstr} mes]
    TestPut 3 "   <$notStarted><$callstr> <$mes>"
    if {$notStarted==0} {break} else {incr i}
  }
@@ -61,18 +63,13 @@ proc hlpWinBitmap {w filedir} {
  set hlp_wgmdxy +${dx}+${dy}; set hlp_wgmx 600
  if {[catch "which gunzip" m1]==0} {set gunzip_installed 1} else {set gunzip_installed 0}
 
- ####################################################################################
- # if you have to modify the following code in order to display the bitmaps         #
- # (neither gunzip nor xdvi available), please inform us so that we can modify      #
- # this procedure for future releases of xtem:   weibezahn@iwd.uni-bremen.de        #
- ####################################################################################
  if {([file exists $hlp_dir${filedir}.xbm]) || \
      ([file exists $hlp_dir${filedir}.xbm.gz] && $gunzip_installed)} {# display bitmap
 
    if {[file exists $hlp_dir${filedir}.xbm.gz]} {# bitmap is packed
-     set xbmfile ".xtem_hlpxbm$hlpCBM";    unlink -nocomplain $xbmfile
+     set xbmfile ".xtem_hlpxbm$hlpCBM"; FileDelete $xbmfile
      TestPut 4 "unpack&display bitmap <$filedir><$xbmfile>"
-     SigChldB; exec gunzip -c $hlp_dir${filedir}.xbm.gz > $xbmfile; SigChldU
+     exec gunzip -c $hlp_dir${filedir}.xbm.gz > $xbmfile
    } else {
      TestPut 4 "display bitmap"
      set xbmfile "$hlp_dir${filedir}.xbm"
@@ -87,19 +84,19 @@ proc hlpWinBitmap {w filedir} {
    scrollbar $w.sb -command "$w.bm yview" -relief sunken;  pack $w.sb -side right -fill y
    canvas    $w.bm -yscrollcommand "$w.sb set" -relief raised -borderwidth 1 -width $hlp_wgmx
 						pack $w.bm -side left -fill both -expand yes
-   if ![file exists $xbmfile] {after 2000; TestPut 4 "@@@@@ NF<$xbmfile><$filedir>; mybell 4"}
+   if ![file exists $xbmfile] {after 3000; TestPut 4 "@@@@@ NF<$xbmfile><$filedir>; mybell 4"}
    if [file exists $xbmfile] {
      $w.bm create bitmap 2 2 -bitmap "@$xbmfile" -anchor nw -tags item \
 		-foreground $tsFgr -background $tsBgr
      $w.bm config -scrollregion [$w.bm bbox all]
    }
-   if {$xbmfile==".xtem_hlpxbm$hlpCBM"} {unlink -nocomplain $xbmfile}
+   if {$xbmfile==".xtem_hlpxbm$hlpCBM"} {FileDelete $xbmfile}
 
  } elseif {[file exists $hlp_dir${filedir}.dvi]} {#bitmap not found, but dvi exists
    TestPut 4 "display dvi-file"
    set x [expr $hlp_wgmx+100]
-   SigChldB; set hlp_pid "$hlp_pid [exec xdvi $hlp_dir${filedir}.dvi \
-		-geometry ${x}x400$hlp_wgmdxy -sidemargin 4.0cm -topmargin 4.3cm &]"; SigChldU
+   set hlp_pid "$hlp_pid [exec xdvi $hlp_dir${filedir}.dvi \
+		-geometry ${x}x400$hlp_wgmdxy -sidemargin 4.0cm -topmargin 4.3cm &]"
 
  } else {# neither bitmap nor dvi exists
    hlpWinInsertInline $w "\n$vv(tsbtm) $hlp_dir$filedir\n" normal
@@ -151,7 +148,7 @@ proc hlpWinFillAlph {w filedir entry} {# read+analyze an AlphabeticalList.htx, f
 }
 
 proc hlpWinFillFile {w filedir entry} {# read+analyze help-file, fill into window w
- global Wh vv hlp_dir hlpC hlpCNr hlpTNr hlpLine hlpUndLine hlpU syntaxmark
+ global Wh vv hlp_dir hlpC hlpCNr hlpTNr hlpLine hlpUndLine hlpU syntaxmark typestack
  TestPut 4 "<$w><$filedir><$entry>"
 
  $w tag configure normal   -font [option get $Wh.normal font text]
@@ -201,27 +198,27 @@ proc hlpWinFillFile {w filedir entry} {# read+analyze help-file, fill into windo
      hlpWinBitmap "$w" "$f[string range $line 8 end]";
 
    } elseif {$first == "@begdescription"} {# prepare description
-     set eoltext "\n"; lvarpush typestack $type; set type normal;  set ctype bold
+     set eoltext "\n"; LvarPush typestack $type; set type normal;  set ctype bold
      set hlpLine "$vv(tsdes)"
    } elseif {$first == "@enddescription"} {#
-     set eoltext "";   set type [lvarpop typestack]
+     set eoltext "";   set type [LvarPop typestack]
 
    } elseif {$first == "@begteletype"} {# prepare teletype
-     set eoltext ""; lvarpush typestack $type; set type teletype; set ctype $type
+     set eoltext ""; LvarPush typestack $type; set type teletype; set ctype $type
    } elseif {$first == "@endteletype"} {#
-     set eoltext "";   set type [lvarpop typestack]
+     set eoltext "";   set type [LvarPop typestack]
 
    } elseif {$first == "@begsyntax"} {# prepare syntax description
-     set eoltext "\n"; lvarpush typestack $type; set type teletype; set ctype bold
+     set eoltext "\n"; LvarPush typestack $type; set type teletype; set ctype bold
      set hlpLine "$vv(tssyn)"
    } elseif {$first == "@endsyntax"} {#
-     set eoltext "";   set type [lvarpop typestack]
+     set eoltext "";   set type [LvarPop typestack]
 
    } elseif {$first == "@begexamples"} {# prepare examples      
-     set eoltext "\n"; lvarpush typestack $type; set type telesmll; set ctype bold
+     set eoltext "\n"; LvarPush typestack $type; set type telesmll; set ctype bold
      set hlpLine "$vv(tsexa)"
    } elseif {$first == "@endexamples"} {#
-     set eoltext "";   set type [lvarpop typestack]
+     set eoltext "";   set type [LvarPop typestack]
      if {[lindex $line 1]!="no_bitmap"} {hlpWinBitmap "$w" "$filedir"}
 
    } elseif {$first == "@begeval"} {# starts evaluation of each text-line before output
@@ -294,7 +291,7 @@ proc hlpWinInsertInline {w text type} {# fills text t into window w with font ty
 	 #
 	 if {[string first "kpsexpand" $cmd]>=0} \
 	     {set kpsFil [lindex $cmd 2]; set cmd [lrange $cmd 0 1]} else {set kpsFil ""}
-	 SigChldB;set res [catch "exec $cmd" mes];SigChldU
+	 set res [catch "exec $cmd" mes]
 	 #
 	 #set res 0; set mes "/usr/share/texmf/doc/helpindex.html";# for test of kpsewhich
 	 #set res 0; set mes "/usr/share/texmf";# for test of old kpsexpand
@@ -383,7 +380,7 @@ proc hlpWinStrPart {} {# returns next part of "hlpLine":
 
 
 global vv Wh Wbm geom edsyntaxhelp tssk edsyntaxchg hlpU hlpWin tsURLcall urlcallexec
-global hlp_dir hlp_width tsFgr tsBgr hlp_pid hlpCBM hlp_bmsuppr hlp_thisbm
+global hlp_dir hlp_width tsFgr tsBgr hlp_pid hlpCBM hlp_bmsuppr hlp_thisbm hlpStack
 
 
 if [winfo exists $Wh] {
@@ -428,8 +425,8 @@ button $Wh.a.2.t -text "$vv(tsat)" -command \
 	{global hlpWin; hlpWinFill $hlpWin "miscellaneous/mainhelp" "mainhelp"}
 Bind3P $Wh.a.2.t 1 hlpWinFill $hlpWin miscellaneous/w_top top
 button $Wh.a.2.b -text "$vv(tsab)" -command {
-  lvarpop hlpStack;  lvarpop hlpStack; global hlpWin
-  set filedir [lvarpop hlpStack]; set entry [lvarpop hlpStack]
+  LvarPop hlpStack;  LvarPop hlpStack; global hlpWin
+  set filedir [LvarPop hlpStack]; set entry [LvarPop hlpStack]
   if {($filedir!="")&&($entry!="")} {hlpWinFill $hlpWin "$filedir" "$entry"}
 }
 Bind3P $Wh.a.2.b 1 hlpWinFill $hlpWin miscellaneous/w_back back
